.. _quickstart:

==========
Quickstart
==========

Downloading and installing
==========================

.. toctree::
   :maxdepth: 1

   users/install

Beginner's guide
================

Michael Notter's Nipype tutorial. `Available here`__

__ https://miykael.github.io/nipype_tutorial/

How should I ask questions or report bugs?
==========================================

* If you find a bug or a suggestion for improvement report it here: `GitHub Issues <https://github.com/nipy/nipype/issues>`_
* If you have a conceptual or clarification question ask it here: `Neurostars <https://neurostars.org/>`_
* If you want to hangout with developers, you can use either `Gitter <https://gitter.im/nipy/nipype>`_ or `Slack <https://brainhack.slack.com/messages/C1FR76RAL>`_

Nipype workshop materials
=========================

Self-assessment questionnaire with links to learning about each piece. `Available here`__

Lecture slides `Available here`__

__ http://nipy.org/workshops/2017-03-boston/review.html
__ http://nipy.org/workshops/2017-03-boston/index.html

`Docker containers <https://hub.docker.com/r/nipype/workshops/tags/>`_

`Github project for lectures <https://github.com/nipy/workshops/tree/gh-pages/2017-03-boston>`_
`Github project for dockerfiles + notebooks <https://github.com/nipy/workshops/tree/master/170327-nipype>`_

`All notebooks visualized <http://nbviewer.jupyter.org/github/nipy/workshops/tree/master/170327-nipype/notebooks/>`_

Learning Resources
==================

`Porcupine <https://timvanmourik.github.io/Porcupine/getting-started/>`_ : create Nipype pipelines using a graphical interface

View the `examples gallery here <https://timvanmourik.github.io/Porcupine/examples/>`_

Developer guides
================

.. toctree::
   :maxdepth: 1

   devel/writing_custom_interfaces

.. include:: links_names.txt
